@@ -1,8 +1,3 @@
-#how to get the stuff to pull up on command to make run
-#conda activate base
-#python
-
-#importing the libraries to do it
 from urllib.request import urlopen as uReq
 from bs4 import BeautifulSoup
 import csv 
@@ -27,10 +22,10 @@ def main():
     for i in range(1,29):
         feb.append(i)
     lengths = {1:31, 2:28, 3:31, 4:30, 5:31, 6:30, 7:31, 8:31, 9:30, 10:31, 11:30, 12:31}
-    directory = "Stat_Sheets"
-    parent_dir = "./"
-    path = os.path.join(parent_dir, directory)
-    os.mkdir(path)
+
+    if os.path.isdir("./Stat_Sheets") == False:
+        os.mkdir("./Stat_Sheets")
+    
     for z in range(1,len(year) + 1):
         for w in range(1, lengths[z] + 1):
             my_url = "http://rotoguru1.com/cgi-bin/hyday.pl?game=fd&mon=" + str(z) + "&day=" + str(w) + "&year=2019" #bs4 setup stuff
@@ -73,7 +68,6 @@ def main():
                     csvwriter.writerow(fields)  
                     csvwriter.writerows(rows) 
                 
-                #https://www.youtube.com/watch?v=XQgXKtPSzUI
-
+                
 if __name__ == "__main__":
     main()
\ No newline at end of file
